<?php

use Doctrine\DBAL\Configuration as DoctrineConfiguration;
use Doctrine\DBAL\Connection;
use Doctrine\DBAL\DriverManager;
use Doctrine\Common\EventManager;
use Doctrine\DBAL\Event\Listeners\SQLSessionInit;
use Doctrine\DBAL\Event\Listeners\OracleSessionInit;
use Psr\Container\ContainerInterface;
use Slim\App;
use Slim\Factory\AppFactory;
use Symfony\Component\Console\Application;
use Symfony\Component\Console\Input\InputOption;

return [
    'settings' => function () {
        return require __DIR__ . '/settings.php';
    },
    
    //Doctrine DBAL
    Connection::class => function (ContainerInterface $container) {
        $config = new DoctrineConfiguration();
        $connectionParams = $container->get('settings')['db'];

        $evm = new EventManager();

        if($connectionParams['driver'] == "sqlsrv") {
            //MSSQL
            $evm->addEventSubscriber(new SQLSessionInit("SET DATEFORMAT dmy;"));
            $connectionParams['platform'] = new \App\DBAL\Platforms\SQLServerPlatform();
        }

       if($connectionParams['driver'] == "oci8") {
            //ORACLEDB
            $evm->addEventSubscriber(new OracleSessionInit());
            $connectionParams['platform'] = new Doctrine\DBAL\Platforms\OraclePlatform();
        }

        return DriverManager::getConnection($connectionParams, $config, $evm);
    },

    //Symfony Console
    Application::class => function (ContainerInterface $container) {
        $application = new Application();

        foreach ($container->get('settings')['commands'] as $class) {
            $application->add($container->get($class));
        }

        return $application;
    },

    //Slim 4
    App::class => function (ContainerInterface $container) {
        AppFactory::setContainer($container);

        return AppFactory::create();
    },
];
