<?php

namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class Layout {
  
  private $layoutService;

  public function __construct(\App\Service\Layout $layoutService) {
    $this->layoutService = $layoutService;
  }

  public function getLayout(Request $request, Response $response) {
    try {
      $params = $request->getQueryParams();
      $layout = $this->layoutService->getLayout($params);

      $response->getBody()->write(json_encode([
        'error' => false,
        'message' => '',
        'data' => $layout,
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    }
  }

  public function saveLayout(Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $flattenedParams = $params['params'];
      $layout = $this->layoutService->saveLayout($flattenedParams);

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => $layout,
        'data'    => [],
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $error = strpos($e->getMessage(), 'ORA');
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $error ? 'Ocorreu um erro ao salvar o layout.' : $e->getMessage(),
        'data'    => []
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    }
  }

  public function updateLayout(Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $flattenedParams = $params['params'];
      $this->layoutService->updateLayout($flattenedParams);

      $response->getBody()->write(json_encode([
        'error' => false,
        'message' => '',
        'data' => [],
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    }
  }

  public function deleteLayout(Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $flattenedParams = $params['params'];
      $layout = $this->layoutService->deleteLayout($flattenedParams);

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => $layout,
        'data'    => [],
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
    ]));

    return $response->withHeader('Content-Type', 'application/json');
    }
  }
}