<?php

namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class RappiMenu
{
    private $rappiMenuService;
    private $integrationsFactory;
    private $rappi;

    public function __construct(
        \App\Service\RappiMenu $rappiMenuService,
        \App\Factory\Integrations $integrationsFactory,
        \App\Integration\Rappi $rappi
    )
    {
        $this->rappiMenuService = $rappiMenuService;
        $this->integrationsFactory = $integrationsFactory;
        $this->rappi = $rappi;
    }

    public function getMenuStatus(Request $request, Response $response)
    {
        try {
            $params = $request->getQueryParams();
            $menuId = $params['merchantId'];
            $storeId = $params['merchantId'];
            $cdIntegracao = $params['cdIntegracao'];

            $token = $this->rappi->getAuthToken();
            $menu  = $this->rappi->getMenuStatus($token,$storeId);
            $menu['lastModifiedAt'] = $this->integrationsFactory->getLastModifiedDate($cdIntegracao,$menuId);
            $data  = [
                "status" => $menu,
            ];

            $response->getBody()->write(
                json_encode([
                    "error" => false,
                    "message" => "",
                    "data" => $data,
                    "pagination" => [
                        "limit" => $params["limit"] ?? 10,
                        "page" => $params["page"] ?? 1,
                    ],
                ])
            );

            return $response->withHeader("Content-Type", "application/json");
        } catch (\Exception $e) {
            $response->getBody()->write(
                json_encode([
                    "error" => true,
                    "message" => $e->getMessage(),
                    "data" => [],
                ])
            );

            return $response->withHeader("Content-Type", "application/json");
        }
    }

    public function listMenus(Request $request, Response $response) {
        try {
            $params = $request->getQueryParams();
            $idIntegracao = $params['cdIntegracao'];
            $storeId = isset($params["merchantId"]) ? strval($params["merchantId"]) : "";
            $token = $this->rappi->getAuthToken();
            $status = $this->rappi->getMenuStatus($token, $storeId);
            $lastModifiedAt = $this->integrationsFactory->getLastModifiedDate($idIntegracao,$storeId);

            $response->getBody()->write(
                json_encode([
                    "error" => false,
                    "message" => "",
                    "data" => [
                                [
                                'lastModifiedAt' => $lastModifiedAt,
                                'menuStatus'         => $status['status'],
                                'menuId'         => $status['storeId'],
                                ]
                            ],
                    "pagination" => [
                        "limit" => $params["limit"] ?? 10,
                        "page" => $params["page"] ?? 1,
                    ],
                ])
            );

            return $response->withHeader("Content-Type", "application/json");
        } catch (\Exception $e) {
            $response->getBody()->write(
                json_encode([
                    "error" => true,
                    "message" => $e->getMessage(),
                    "data" => [],
                ])
            );

            return $response->withHeader("Content-Type", "application/json");
        }
    }

    public function getMenu(Request $request, Response $response)
    {
        try {
            $params = $request->getQueryParams();
            $storeId = isset($params["merchantId"]) ? strval($params["merchantId"]) : "";

            $token = $this->rappi->getAuthToken();
            $menu  = $this->rappi->getMenu($token, $storeId);
            $formattedMenu = $this->rappiMenuService->formatData($menu);

            $response->getBody()->write(
                json_encode([
                    "error" => false,
                    "message" => "",
                    "data" => $formattedMenu,
                    "pagination" => [
                        "limit" => $params["limit"] ?? 10,
                        "page" => $params["page"] ?? 1,
                    ],
                ])
            );

            return $response->withHeader("Content-Type", "application/json");
        } catch (\Exception $e) {
            $response->getBody()->write(
                json_encode([
                    "error" => true,
                    "message" => $e->getMessage(),
                    "data" => [],
                ])
            );

            return $response->withHeader("Content-Type", "application/json");
        }
    }

    public function updateMenu(Request $request, Response $response)
    {
        try {
            $params = $request->getParsedBody();
            $token = $this->rappi->getAuthToken();
            $this->rappiMenuService->updateMenu($token,$params);

            $response->getBody()->write(
                json_encode([
                    "error" => false,
                    "message" => "Success"
                ])
            );
            return $response->withHeader("Content-Type", "application/json");
        } catch (\Exception $e) {
            $response->getBody()->write(
                json_encode([
                    "error" => true,
                    "message" => $e->getMessage(),
                    "relatedItems" => $params['items'] ?? null,
                ])
            );

            return $response->withHeader("Content-Type", "application/json");
        }
    }

}
