<?php
namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class Store {

    private $storeService;
    private $util;

    public function __construct(
        \App\Service\Store $storeService,
        \App\Util\Util $util
    ) {

        $this->storeService = $storeService;
        $this->util = $util;
    }

    public function getStores(Request $request, Response $response) {
        try {
            $params = $request->getParsedBody();
            
            $dataset = $this->storeService->getStores();

            $response->getBody()->write(json_encode([
                'error' => false,
                'message' => '',
                'data' => $dataset
            ]));
    
            return $response->withHeader('Content-Type', 'application/json');
        } catch (\Exception $e) {
            $response->getBody()->write(json_encode([
                'error'   => true,
                'message' => $e->getMessage(),
                'data'    => []
            ]));

            return $response->withHeader('Content-Type', 'application/json');
        }
    }



    public function getStoreScheduledIntervals(Request $request, Response $response) {
        try {
            $params = $request->getParsedBody();
            
            $CDFILIAL = $params['CDFILIAL'];
            $CDLOJA   = $params['CDLOJA'];
            
            $dataset = $this->storeService->getStoreScheduledIntervals($CDFILIAL, $CDLOJA);

            $response->getBody()->write(json_encode([
                'error' => false,
                'message' => '',
                'data' => $dataset
            ]));
    
            return $response->withHeader('Content-Type', 'application/json');
        } catch (\Exception $e) {
            $response->getBody()->write(json_encode([
                'error'   => true,
                'message' => $e->getMessage(),
                'data'    => []
            ]));

            return $response->withHeader('Content-Type', 'application/json');
        }
    }


}