<?php

namespace App\Integration;
use App\Integration\ApiRequest;

class IFood extends ApiRequest {
    private $url = '';
    private $authUrl = '';
    
    function __construct() {
        $this->url = $_ENV['IFOOD_URL'];
        $this->authUrl = $_ENV['IFOOD_AUTH_URL'];
    }
    
    public function getAuthToken() {
        $result = parent::get($this->authUrl);
        $resultJson = json_decode($result, true);
        return $resultJson['authToken'];
    }
    
    private function getTokenField($token) {
        return ["Authorization: Bearer $token"];
    }
    
    private function handleTokenHeader($token) {
        return ['header' => $this->getTokenField($token)];
    }
    
    private function sendRequest($url, $options = []) {
        $token = $options['token'] ?? $this->getAuthToken();
        if (empty($options)) {
            $options = $this->handleTokenHeader($token);
        } else {
            $options['header'] = $options['header'] ?? [];
            $options['header'][] = $this->getTokenField($token)[0];
        }
        $result = parent::send($url, $options);
        if (isset($options['stripSlashes'])) {
            $result = stripslashes($result);
        }
        if (isset($options['parseJson'])) {
            $result = json_decode($result, true);
        }
        return $result;
    }
    
    public function getMerchantStatus($merchantId, $token = null) {
        $url = $this->url . "/merchant/v1.0/merchants/$merchantId/status";
        return $this->sendRequest($url, ['parseJson' => true, 'token' => $token ]);
    }
    
    public function getMerchantInterruptions($merchantId, $token = null) {
        $url = $this->url . "/merchant/v1.0/merchants/$merchantId/interruptions";
        return $this->sendRequest($url, ['parseJson' => true, 'token' => $token ]);
    }
    
    public function getOpeningHours($merchantId, $token = null) {
        $url = $this->url . "/merchant/v1.0/merchants/$merchantId/opening-hours";
        return $this->sendRequest($url, ['parseJson' => true, 'token' => $token ]);
    }

    public function getMenu($merchantId, $menuId, $token = null) {
        $url = $this->url . "/catalog/v2.0/merchants/$merchantId/catalogs/$menuId/categories?includeItems=true";
        return $this->sendRequest($url, ['parseJson' => true, 'stripSlashes' => true, 'token' => $token ]);
    }
    
    public function getMenuId($merchantId, $token = null) {
        $url = $this->url . "/catalog/v2.0/merchants/$merchantId/catalogs";
        return $this->sendRequest($url, ['parseJson' => true, 'stripSlashes' => true, 'token' => $token ]);
    }
    
    public function getMerchantInfo($merchantId, $token = null) {
        $url = $this->url . "/merchant/v1.0/merchants/$merchantId";
        return $this->sendRequest($url, ['parseJson' => true, 'stripSlashes' => true, 'token' => $token ]);
    }
    
    public function setOptionExternalCode($merchantId, $data, $token = null) {
        $url = $this->url . "/catalog/v2.0/merchants/$merchantId/options/externalCode";
        return $this->sendRequest($url, ['data' => $data, 'method' => 'PATCH']);
    }
    
    public function setItemExternalCode($merchantId, $data, $token = null) {
        $url = $this->url . "/catalog/v2.0/merchants/$merchantId/items/externalCode";
        return $this->sendRequest($url, ['data' => $data, 'method' => 'PATCH']);
    }
}