<?php
namespace App\Report\Format;

use Dompdf\Dompdf;
use Dompdf\Options;
use Twig\Environment;
use Twig\Loader\FilesystemLoader;
use App\Report\IReport;

class PDF implements IReport {
  private $defaultOptions = [
    'size' => 'A4',
    'orientation' => 'landscape',
    'isHtml5ParserEnabled' => true,
    'isPhpEnabled' => true,
    'isRemoteEnabled' => true,
  ];

  public function export($data, $customOptions = []) {
    $options = array_merge($this->defaultOptions, $customOptions);
    $loader = new FilesystemLoader(__DIR__ . '/../Template');
    $twig = new Environment($loader);
    $templateName = $data['report'];
    $template = $twig->load("$templateName.twig");

    $dompdfOptions = new Options();
    $dompdfOptions ->set('isHtml5ParserEnabled', $options['isHtml5ParserEnabled']);
    $dompdfOptions ->set('isPhpEnabled', $options['isPhpEnabled']);
    $dompdfOptions ->setIsRemoteEnabled($options['isRemoteEnabled']);
    
    $dompdf = new Dompdf($dompdfOptions);
    $dompdf->loadHtml($template->render($data));
    $dompdf->setPaper($options['size'], $options['orientation']);
    $dompdf->render();

    return $dompdf->output();
  }
}